@@ -1,6 +1,8 @@
 describe.bprobit<-function(){
 category <- "dichotomous"
 description  <- "Bivariate Probit Regression for Dichotomous Dependent Variables"
+authors <- c()
+year <- 2007
 package <-list(	name 	="VGAM",
 		version	="0.6"
 		)
@@ -14,5 +16,5 @@ parameters$rho<-list(equations=c(1,1),
 			tagsAllowed=FALSE,
 			depVar=FALSE,
 			expVar=TRUE)
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
