@@ -35,6 +35,14 @@ sim.default <- function(object, x=NULL, x1=NULL, num=c(1000, 100),
     else
       simpar <- prev
   }
+  fn <- paste("zelig4", getzelig(object), sep = "")
+  if(exists(fn)){
+    if(!bootstrap)
+      simpar <- do.call(fn, list(object=object, simpar=simpar, x=x, x1=x1, bootstrap=bootstrap, bootfn=bootfn))
+    else
+	simpar <- do.call(fn, list(object=object, simpar=simpar, x=x, x1=x1, bootstrap=bootstrap, bootfn=bootfn, dta=dta))
+  }
+    
   simqi <- qi(object, simpar = simpar, x = x, x1 = x1, y = NULL)
   c <- match.call()
   c[[1]] <- as.name("sim")
